@@ -8,6 +8,7 @@ Usage::
     from mypy_boto3_budgets import (
         BudgetsClient,
         Client,
+        DescribeBudgetPerformanceHistoryPaginator,
         DescribeBudgetsPaginator,
         DescribeNotificationsForBudgetPaginator,
         DescribeSubscribersForNotificationPaginator,
@@ -18,6 +19,7 @@ Usage::
     client: BudgetsClient = boto3.client("budgets")
     session_client: BudgetsClient = session.client("budgets")
 
+    describe_budget_performance_history_paginator: DescribeBudgetPerformanceHistoryPaginator = client.get_paginator("describe_budget_performance_history")
     describe_budgets_paginator: DescribeBudgetsPaginator = client.get_paginator("describe_budgets")
     describe_notifications_for_budget_paginator: DescribeNotificationsForBudgetPaginator = client.get_paginator("describe_notifications_for_budget")
     describe_subscribers_for_notification_paginator: DescribeSubscribersForNotificationPaginator = client.get_paginator("describe_subscribers_for_notification")
@@ -25,6 +27,7 @@ Usage::
 """
 from mypy_boto3_budgets.client import BudgetsClient
 from mypy_boto3_budgets.paginator import (
+    DescribeBudgetPerformanceHistoryPaginator,
     DescribeBudgetsPaginator,
     DescribeNotificationsForBudgetPaginator,
     DescribeSubscribersForNotificationPaginator,
@@ -36,6 +39,7 @@ Client = BudgetsClient
 __all__ = (
     "BudgetsClient",
     "Client",
+    "DescribeBudgetPerformanceHistoryPaginator",
     "DescribeBudgetsPaginator",
     "DescribeNotificationsForBudgetPaginator",
     "DescribeSubscribersForNotificationPaginator",
